@@ -6,6 +6,10 @@
 #'        \code{"dir/*"}.
 #' @param sep character to use instead of spaces.
 #'
+#' @note
+#' This function treats \file{\%20} in filenames as a space and converts to
+#' \code{sep}.
+#'
 #' @return \code{TRUE} for success, \code{FALSE} for failure, invisibly.
 #'
 #' @seealso
@@ -29,9 +33,10 @@ convert.spaces <- function(file, sep="_")
   ## Include both glob matches and filenames without asterisk,
   ## in case some filenames without asterisk are not found
   from <- sort(unique(c(Sys.glob(file), file[!grepl("\\*", file)])))
-  from <- grep(" ", from, value=TRUE)
+  ## If file is "A B/x y.txt" then convert to "A B/x_y.txt"
+  from <- from[grep(" |%20", basename(from))]
 
-  to <- chartr(" ", sep, from)
+  to <- file.path(dirname(from), gsub(" |%20", sep, basename(from)))
 
   out <- suppressWarnings(mapply(file.rename, from, to))
   if(length(out) == 0)
