@@ -11,13 +11,18 @@
 #'        Alternatively, a single number if the data cover only one year. If the
 #'        data do not cover specific years, this metadata field can be
 #'        suppressed using \code{period = FALSE}.
+#' @param access data access code: \code{"OSPAR"}, \code{"Public"}, or
+#'        \code{"Restricted"}.
 #' @param source where the data are copied/downloaded from. This can be a URL,
-#'        filename, or the special value \code{"file"}.
-#' @param file optional filename to save the draft metadata to a file.
-#' @param data.dir directory containing data files.
-#' @param data.files data filenames. The default is all files inside
-#'        \code{data.dir}.
+#'        filename, special value \code{"file"}, or special value
+#'        \code{"script"}.
+#' @param file optional filename to save the draft metadata to a file. The value
+#'        \code{TRUE} can be used as shorthand for \code{"bootstrap/DATA.bib"}.
 #' @param append whether to append metadata entries to an existing file.
+#' @param data.files data files to consider. The default is all folders and
+#'        files inside \verb{bootstrap/initial/data}.
+#' @param data.scripts data scripts to consider. The default is all \verb{*.R}
+#'        files in the \verb{bootstrap} folder.
 #'
 #' @details
 #' Typical usage is to specify \code{originator}, while using the default values
@@ -25,30 +30,32 @@
 #' be specified to facilitate completing the entries after creating the initial
 #' draft.
 #'
-#' The special value \verb{source = "file"} is described in the
-#' \code{\link{process.bib}} help page, along with other metadata information.
+#' The data access codes come from \url{https://vocab.ices.dk/?ref=1435}.
+#'
+#' The special values \verb{source = "file"} and \verb{source = "script"} are
+#' described in the \code{\link{process.bib}} help page, along with other
+#' metadata information.
 #'
 #' The default value \code{file = ""} prints the initial draft in the console,
 #' instead of writing it to a file. The output can then be pasted into a file to
 #' edit further, without accidentally overwriting an existing metadata file.
 #'
-#' This function is intended to be called from the top directory of a TAF
-#' analysis which contains a \file{bootstrap/initial/data} directory, as
-#' reflected in the default value of \code{data.dir}.
-#'
-#' @return
-#' Object of class \verb{Bibtex}.
+#' @return Object of class \verb{Bibtex}.
 #'
 #' @note
+#' This function is intended to be called from the top directory of a TAF
+#' analysis. It looks for data files inside \verb{bootstrap/initial/data} folder
+#' and data scripts inside \verb{bootstrap}.
+#'
 #' After creating the initial draft, the user can complete the description of
-#' each data file inside the \verb{title} field and look into each file to
+#' each data entry inside the \verb{title} field and look into each file to
 #' specify the \verb{period} that the data cover.
 #'
 #' @seealso
 #' \code{\link{period}} pastes two years to form a \code{period} string.
 #'
 #' \code{\link{draft.software}} creates an initial draft version of a
-#' \file{SOFTWARE.bib} metadata file.
+#' \verb{SOFTWARE.bib} metadata file.
 #'
 #' \code{\link{process.bib}} reads and processes metadata entries. The help page
 #' contains example metadata entries and commentary.
@@ -61,31 +68,45 @@
 #' draft.data("WGEF", 2015)
 #'
 #' # Export to file
-#' draft.data("WGEF", 2015, file="bootstrap/DATA.bib")
+#' draft.data("WGEF", 2015, file=TRUE)
 #' }
 #'
 #' @export
 
 draft.data <- function(originator=NULL, year=format(Sys.time(),"%Y"),
-                       title=NULL, period=NULL, source="file", file="",
-                       data.dir="bootstrap/initial/data",
-                       data.files=dir(data.dir,recursive=TRUE), append=FALSE)
+                       title=NULL, period=NULL, access="Public", source=NULL,
+                       file="", append=FALSE,
+                       data.files=dir("bootstrap/initial/data"),
+                       data.scripts=dir("bootstrap",pattern="\\.R$"))
 {
-  if(length(data.files) == 0)
-    stop("'data.files' is an empty vector")
+  access.vocab <- c("OSPAR", "Public", "Restricted")  # vocab.ices.dk/?ref=1435
+  if(!is.character(access) || !all(as.character(access) %in% access.vocab))
+    stop("'access' values must be \"",
+         paste(access.vocab, collapse="\", \""), "\"")
+
+  data.scripts <- file_path_sans_ext(data.scripts)
+  entries <- c(data.files, data.scripts)
+  if(length(entries) == 0)
+    stop("no data (bootstrap/initial/data/*) ",
+         "or data scripts (bootstrap/*.R) found")
+  if(is.null(source))
+    source <- rep(c("file","script"),
+                  c(length(data.files),length(data.scripts)))
 
   ## 1  Assemble metadata
-  line1 <- paste0("@Misc{", data.files, ",")
+  line1 <- paste0("@Misc{", entries, ",")
   line2 <- paste0("  originator = {", originator, "},")
   line3 <- paste0("  year       = {", year, "},")
   line4 <- paste0("  title      = {", title, "},")
   line5 <- paste0("  period     = {", period, "},")
-  line6 <- paste0("  source     = {", source, "},")
-  line7 <- "}"
-  line8 <- ""
+  line6 <- paste0("  access     = {", access, "},")
+  line7 <- paste0("  source     = {", source, "},")
+  line8 <- "}"
+  line9 <- ""
 
   ## 2  Combine and format
-  out <- data.frame(line1, line2, line3, line4, line5, line6, line7, line8)
+  out <- data.frame(line1, line2, line3, line4, line5, line6, line7, line8,
+                    line9)
   out <- c(t(out))
   if(identical(period, FALSE))
     out <- out[substr(out,3,8) != "period"]  # remove 'period' line if FALSE
@@ -93,6 +114,10 @@ draft.data <- function(originator=NULL, year=format(Sys.time(),"%Y"),
   class(out) <- "Bibtex"
 
   ## 3  Export
+  if(identical(file, TRUE))
+    file <- "bootstrap/DATA.bib"
+  if(identical(file, FALSE))
+    file <- ""
   ## No write() when file="", to ensure quiet assignment x <- draft.data()
   if(file == "")
   {
